==> jira-projects-plugin-4.3.2.jar: sidebar/project-shortcuts/dialogs/Delete.js <==
(function($) {
    "use strict";

    AJS.namespace("JIRA.Projects.Sidebar.ProjectShortcuts.Dialogs.Delete");

    JIRA.Projects.Sidebar.ProjectShortcuts.Dialogs.Delete = JIRA.Projects.Libs.Marionette.ItemView.extend({
        template: JIRA.Projects.Sidebar.ProjectShortcuts.Templates.deleteDialog,
        ui: {
            inputs: "input, button",
            submit: ".project-shortcuts-submit",
            cancel: ".project-shortcuts-cancel"
        },
        events: {
            "click @ui.cancel": function cancel(e) {
                e.preventDefault();
                this.dialog.hide();
            },
            "click @ui.submit": function formSubmit(e) {
                e.preventDefault();
                this.model.destroy({wait: true});
            }
        },
        modelEvents: {
            "remove:start": function removeStart() {
                this.ui.inputs.prop("disabled", true);
                this.ui.submit.addClass("loading");
                this.ui.submit.spin({className: "spinner"});
            },
            "remove:finish": function removeFinish() {
                this.ui.inputs.prop("disabled", false);
                this.ui.submit.removeClass("loading");
                this.ui.submit.spinStop({className: "spinner"});
                this.dialog.hide();
                JIRA.trace("jira.projects.shortcuts.deleted");
            },
            "remove:failure": function removeFailure(errorData) {
                if (errorData.message || (errorData.errorMessages && errorData.errorMessages.length > 0)) {
                    var flag = require('aui/flag');
                    flag({
                        type: "error",
                        title: AJS.I18n.getText('project.shortcuts.dialog.error.general.delete'),
                        close: "auto",
                        body: errorData.message || errorData.errorMessages[0]
                    });
                }
            }
        },
        initialize: function initialize() {
            this.render();
            this.$el.appendTo("body");

            this.dialog = AJS.dialog2(this.$el);
            this.dialog.show();
            var instance = this;
            this.dialog.on("hide", function() {
                _.defer(function () {
                    instance.destroy();
                });
            });
        },
        onRender: function onRender() {
            this.unwrapTemplate();
        }
    });
})(AJS.$);

==> jira-projects-plugin-6.0.5.jar: sidebar/project-shortcuts/dialogs/Delete.js <==
define('jira/projects/sidebar/project-shortcuts/dialogs/delete', [
    "jira/projects/sidebar/project-shortcuts/templates",
    "jira/util/formatter",
    "jira/util/logger",
    "jira/flag",
    "jira/projects/libs/marionette",
    "underscore"
], function(Templates, formatter, logger, flag, Marionette, _) {
    "use strict";

    return Marionette.ItemView.extend({
        template: Templates.deleteDialog,
        ui: {
            inputs: "input, button",
            submit: ".project-shortcuts-submit",
            cancel: ".project-shortcuts-cancel"
        },
        events: {
            "click @ui.cancel": function cancel(e) {
                e.preventDefault();
                this.dialog.hide();
            },
            "click @ui.submit": function formSubmit(e) {
                e.preventDefault();
                this.model.destroy({wait: true});
            }
        },
        modelEvents: {
            "remove:start": function removeStart() {
                this.ui.inputs.prop("disabled", true);
                this.ui.submit.addClass("loading");
                this.ui.submit[0].busy();
            },
            "remove:finish": function removeFinish() {
                this.ui.inputs.prop("disabled", false);
                this.ui.submit.removeClass("loading");
                this.ui.submit[0].idle();
                this.dialog.hide();
                logger.trace("jira.projects.shortcuts.deleted");
            },
            "remove:failure": function removeFailure(errorData) {
                if (errorData.message || (errorData.errorMessages && errorData.errorMessages.length > 0)) {
                    flag({
                        type: "error",
                        title: formatter.I18n.getText('project.shortcuts.dialog.error.general.delete'),
                        close: "auto",
                        body: errorData.message || errorData.errorMessages[0]
                    });
                }
            }
        },
        initialize: function initialize() {
            this.render();
            this.$el.appendTo("body");

            this.dialog = AJS.dialog2(this.$el);
            this.dialog.show();
            var instance = this;
            this.dialog.on("hide", function() {
                _.defer(function () {
                    instance.destroy();
                });
            });
        },
        onRender: function onRender() {
            this.unwrapTemplate();
        }
    });
});

AJS.namespace('JIRA.Projects.Sidebar.ProjectShortcuts.Dialogs.Delete', null, require('jira/projects/sidebar/project-shortcuts/dialogs/delete'));
